@@ -1,2 +1,2 @@
 from .utils import OptStr, OptStrList, StrList, OptStrsDict, StrsDict
-from .msal_client_config import client_config, MSALPolicies
+from .msal_client_config import MSALPolicies, MSALClientConfig
